AdminLTE 3 | Kanban Board

# Kanban Board

### Backlog

##### Create Labels

#3
Bug
Feature
Enhancement
Documentation
Examples

##### Create Issue template

#4
Bug Report
Feature Request

##### Create PR template

#6

##### Create Actions

#7

Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus.

### To Do

##### Create first milestone

#5

### In Progress

##### Update Readme

#2

Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus.

### Done

##### Create repo

#1